<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" 
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xmlns="http://www.w3.org/1999/xhtml">

<head>
<title>{{ TITLE }}</title>

<!-- metadata -->
<meta http-equiv="content-type" content="text/html;charset=utf-8" />
<meta name="generator" content="pydozeoff" />
<meta name="version" content="{{ VERSION }}" />
<meta name="presdate" content="{{ DATE }}" />
<meta name="author" content="{{ SPEAKER }}" />
<meta name="company" content="{{ COMPANY }}" />

<!-- configuration parameters -->
<meta name="defaultView" content="{{ DEFAULT_VIEW }}" />
<meta name="controlVis" content="{{ CONTROL_VIS }}" />

<!-- style sheet links -->
<link rel="stylesheet" href="theme/slides.css" type="text/css" media="projection" id="slideProj" />
<link rel="stylesheet" href="theme/outline.css" type="text/css" media="screen" id="outlineStyle" />
<link rel="stylesheet" href="theme/print.css" type="text/css" media="print" id="slidePrint" />
<link rel="stylesheet" href="theme/opera.css" type="text/css" media="projection" id="operaFix" />

{% code_highlight_css %}

<!-- script links -->
<script src="theme/slides.js" type="text/javascript"></script>

</head>
<body>

<div class="layout">
<div id="controls"><!-- DO NOT EDIT --></div>
<div id="currentSlide"><!-- DO NOT EDIT --></div>
<div id="header"></div>
<div id="footer">
<h1>{{ TITLE }}</h1>
<h2>{{ LOCATION }}</h2>
</div>

</div>


<div class="presentation">

{% for slide in slides %}
<div class="slide {{ slide.classes }}">
    {{ slide.content }}
</div>
{% endfor %}

</div>

</body>
</html>
